@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Task::Kensho::ExcelCSV;
-BEGIN {
-  $Task::Kensho::ExcelCSV::AUTHORITY = 'cpan:PERIGRIN';
-}
-# git description: v0.35-28-gedd4887
-$Task::Kensho::ExcelCSV::VERSION = '0.36';
+# git description: v0.36-25-g47364ce
+$Task::Kensho::ExcelCSV::VERSION = '0.37';
 # ABSTRACT: A Glimpse at an Enlightened Perl: Excel/CSV
 
 __END__
@@ -20,7 +17,7 @@ Task::Kensho::ExcelCSV - A Glimpse at an Enlightened Perl: Excel/CSV
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -69,10 +66,10 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
-=head2 L<Task::Kensho::ExcelCSV>: Excel/CSV
-
 =for stopwords CSV
 
+=head2 L<Task::Kensho::ExcelCSV>: Excel/CSV
+
 =head3 L<Spreadsheet::ParseExcel::Simple>
 
 A simple interface to Excel data
@@ -122,4 +119,24 @@ This software is copyright (c) 2008 by Chris Prather.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Leo Lapworth <leo@cuckoo.org>
+
+=item *
+
+Chris Nehren <apeiron@cpan.org>
+
+=back
+
 =cut
